IndividualSpec — alfred3_interact

Skip to main content
`Ctrl`+`K`

# IndividualSpec

class alfred3_interact.spec.IndividualSpec(nslots: int, name: str, respect_version: bool = True, inclusive: bool = False, count: bool = True)

  Bases: `SequentialSpec`

  Interface for defining an ‘individual group spec’.

  The IndividualSpec can be used to include an individual condition in a MatchMaker speclist. The usecase arises, if you want to randomize the assignment of participants to at least one group specification and at least one individual condition.

  Parameters

    - nslots (int) – Maximum number of sessions that should be created based on this spec.

    - name (str) – A unique identifier for the spec.

    - respect_version (bool) – If True, the quota will only include sessions that run on the same experiment version. This setting makes sure that there’s no strange behavior if you make changes to an ongoing experiment. Defaults to True.

    - inclusive (bool) – If False (default), the quota will only assign a slot, if there are no pending sessions for that slot. See `SequentialGroupQuota` / `ParallelGroupQuota` for more details.

  See also

  See `SequentialSpec` for an interface for defining a sequential group and `ParallelSpec` for defining a parallel group.

  Methods

  `full` |

  Attributes

  `group_type` |
  `pattern` |
  `quota` | Access to the spec's `SequentialGroupQuota`, or `ParallelGroupQuota`, depending on the type of spec.